@@ -1,17 +1,15 @@
-from __future__ import unicode_literals, division, absolute_import
-from builtins import *  # noqa pylint: disable=unused-import, redefined-builtin
-from future.moves.urllib.parse import urlencode
+from urllib.parse import urlencode
 
-import logging
+from loguru import logger
+from requests import RequestException
 
 from flexget import plugin
 from flexget.event import event
-from requests import RequestException
 
-log = logging.getLogger('sabnzbd')
+logger = logger.bind(name='sabnzbd')
 
 
-class OutputSabnzbd(object):
+class OutputSabnzbd:
     """
     Example::
 
@@ -30,6 +28,7 @@ class OutputSabnzbd(object):
         pp: ...
         priority: ...
     """
+
     schema = {
         'type': 'object',
         'properties': {
@@ -62,13 +61,12 @@ class OutputSabnzbd(object):
             params['ma_username'] = config['username']
         if 'password' in config:
             params['ma_password'] = config['password']
-        params['mode'] = 'addurl'
         return params
 
     def on_task_output(self, task, config):
         for entry in task.accepted:
             if task.options.test:
-                log.info('Would add into sabnzbd: %s' % entry['title'])
+                logger.info('Would add into sabnzbd: {}', entry['title'])
                 continue
 
             params = self.get_params(config)
@@ -82,22 +80,29 @@ class OutputSabnzbd(object):
             # add cleaner nzb name (undocumented api feature)
             params['nzbname'] = ''.join([x for x in entry['title'] if ord(x) < 128])
 
+            # check whether file is local or remote
+            if entry['url'].startswith('file://'):
+                params['mode'] = 'addlocalfile'
+                params['name'] = entry['location']
+            else:
+                params['mode'] = 'addurl'
+
             request_url = config['url'] + urlencode(params)
-            log.debug('request_url: %s' % request_url)
+            logger.debug('request_url: {}', request_url)
             try:
                 response = task.requests.get(request_url)
             except RequestException as e:
-                log.critical('Failed to use sabnzbd. Requested %s' % request_url)
-                log.critical('Result was: %s' % e.args[0])
+                logger.critical('Failed to use sabnzbd. Requested {}', request_url)
+                logger.critical('Result was: {}', e.args[0])
                 entry.fail('sabnzbd unreachable')
                 if task.options.debug:
-                    log.exception(e)
+                    logger.exception(e)
                 continue
 
             if 'error' in response.text.lower():
                 entry.fail(response.text.replace('\n', ''))
             else:
-                log.info('Added `%s` to SABnzbd' % (entry['title']))
+                logger.info('Added `{}` to SABnzbd', entry['title'])
 
 
 @event('plugin.register')
